@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-1 Brendan Cully <brendan@kublai.com>
+ * Copyright (C) 2000-5 Brendan Cully <brendan@kublai.com>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -21,11 +21,14 @@
 #ifndef _MUTT_SASL_H_
 #define _MUTT_SASL_H_ 1
 
+#ifdef USE_SASL2
+#include <sasl/sasl.h>
+#else
 #include <sasl.h>
+#endif
 
 #include "mutt_socket.h"
 
-int mutt_sasl_start (void);
 int mutt_sasl_client_new (CONNECTION*, sasl_conn_t**);
 sasl_callback_t* mutt_sasl_get_callbacks (ACCOUNT*);
 int mutt_sasl_interact (sasl_interact_t*);
@@ -38,16 +41,20 @@ typedef struct
   const unsigned int* pbufsize;
 
   /* read buffer */
+#ifdef USE_SASL2
+  const char *buf;
+#else
   char* buf;
+#endif
   unsigned int blen;
   unsigned int bpos;
 
   /* underlying socket data */
   void* sockdata;
-  int (*open) (CONNECTION* conn);
-  int (*close) (CONNECTION* conn);
-  int (*read) (CONNECTION* conn);
-  int (*write) (CONNECTION* conn, const char* buf, size_t count);
+  int (*msasl_open) (CONNECTION* conn);
+  int (*msasl_close) (CONNECTION* conn);
+  int (*msasl_read) (CONNECTION* conn, char* buf, size_t len);
+  int (*msasl_write) (CONNECTION* conn, const char* buf, size_t count);
 }
 SASL_DATA;
 
