@@ -21,6 +21,10 @@
 
 /* Generally useful, pgp-related functions. */
 
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
